Package "narcissistic" has one submodule also named "narcissistic".
The submodule "narcissistic" has one function "narcissistic".
You can enter a number to this function in order to check if it is a narcissistic number.